#[non_exhaustive]pub enum StrictResolveError {
Fatal(ResolveError),
Partial(PartialResolveError),
}Expand description
Unified error for resolve_strict.
Covers both fatal resolution failures and non-fatal ref errors that are promoted to errors in strict mode.
Inspecting failures
use serde_json::json;
use openapi_deref::{resolve_strict, StrictResolveError};
let spec = json!({ "a": { "$ref": "#/nope" } });
let err = resolve_strict(&spec).unwrap_err();
// Access partial value and ref errors without pattern matching
if let Some(value) = err.partial_value() {
assert_eq!(value["a"]["$ref"], "#/nope");
}
assert_eq!(err.ref_errors().len(), 1);Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Fatal(ResolveError)
Fatal resolution error (e.g. depth limit exceeded).
Partial(PartialResolveError)
One or more refs could not be resolved.
Implementations
Sourceimpl StrictResolveError
impl StrictResolveError
Sourcepub fn partial_value(&self) -> Option<&Value>
pub fn partial_value(&self) -> Option<&Value>
Returns the partially resolved value if this was a partial failure.
Returns None for fatal errors where no value was produced.
Sourcepub fn ref_errors(&self) -> &[RefError]
pub fn ref_errors(&self) -> &[RefError]
Returns ref-level errors if this was a partial failure.
Returns an empty slice for fatal errors.